##  Table View
In the inventory, switching to the table view mode displays factsheets in a tabular format, with factsheets in rows and their attributes as columns. This offers you a structured way to visualize your inventory data and is valuable for conducting comparative analyses. You can easily scan, sort, and compare data across different criteria and make informed decisions. More importantly, you can add or edit data directly in the table, just as you would in a spreadsheet.
You switch from list view to table view by selecting the As Table icon.
![](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio451a225f37a74de7a56d436235471a2d_LowRes.png)
Switching to Table View in the Inventory
By default, the table shows basic information such as fact sheet name and type, but you can add further columns to display more attributes of the fact sheets. To add or hide columns in the table, do the following:
  1. At the top right of the table, click the eye icon. This opens a panel for selecting the fact sheet attributes you want to include as columns.
  2. From under the Inactive columns section, choose and add the column to be shown by clicking the '+' icon. You can also search for a column by its title.
  3. Under the Active columns section, drag and reorder the items as needed. To exclude an existing column, click 'x' next to the item.


![](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio08d8a1ab275f46ee8a4e97981dd3dd03_LowRes.gif)
Show or Hide Columns in the Table View
**Note**
The columns available for selection depend on the type of fact sheet you are working with. If you haven't filtered for a specific fact sheet type, some columns—particularly those relevant only to certain fact sheet types, like specific fields or tag groups—will not be visible or available for selection.
